@@ -16,7 +16,7 @@ from __future__ import print_function
 import datetime, py_compile, os, subprocess, sys, tempfile
 
 from uncompyle6 import verify, IS_PYPY, PYTHON_VERSION
-from xdis.code import iscode
+from xdis import iscode
 from xdis.magics import sysinfo2float
 from uncompyle6.disas import check_object_path
 from uncompyle6.semantics import pysource
@@ -102,7 +102,7 @@ def decompile(
     )
     if PYTHON_VERSION < 3.0 and bytecode_version >= 3.0:
         write(
-            "# Warning: this version has problems handling the Python 3 byte type in contants properly.\n"
+            '# Warning: this version has problems handling the Python 3 "byte" type in constants properly.\n'
         )
 
     if co.co_filename:
@@ -183,7 +183,7 @@ def decompile_file(
 
     filename = check_object_path(filename)
     code_objects = {}
-    (version, timestamp, magic_int, co, is_pypy, source_size) = load_module(
+    (version, timestamp, magic_int, co, is_pypy, source_size, sip_hash) = load_module(
         filename, code_objects
     )
 
