@@ -37,7 +37,7 @@ from __future__ import print_function
 
 from copy import copy
 
-from xdis.code import iscode
+from xdis import iscode
 from xdis.bytecode import (
     op_has_argument, instruction_size,
     _get_const_info)
@@ -138,14 +138,21 @@ class Scanner2(Scanner):
         if classname:
             classname = '_' + classname.lstrip('_') + '__'
 
-            free = [ self.unmangle_name(name, classname)
+            if hasattr(co, "co_cellvars"):
+                free = [ self.unmangle_name(name, classname)
                      for name in (co.co_cellvars + co.co_freevars) ]
+            else:
+                free = ()
+
             names = [ self.unmangle_name(name, classname)
                       for name in co.co_names ]
             varnames = [ self.unmangle_name(name, classname)
                          for name in co.co_varnames ]
         else:
-            free = co.co_cellvars + co.co_freevars
+            if hasattr(co, "co_cellvars"):
+                free = co.co_cellvars + co.co_freevars
+            else:
+                free = ()
             names = co.co_names
             varnames = co.co_varnames
         return free, names, varnames
@@ -396,7 +403,7 @@ class Scanner2(Scanner):
 
         if show_asm in ('both', 'after'):
             for t in tokens:
-                print(t.format(line_prefix='L.'))
+                print(t.format(line_prefix=""))
             print()
         return tokens, customize
 
