@@ -35,7 +35,7 @@ Finally we save token information.
 
 from __future__ import print_function
 
-from xdis.code import iscode
+from xdis import iscode
 from xdis.bytecode import instruction_size, _get_const_info
 
 from uncompyle6.scanner import Token, parse_fn_counts
@@ -379,7 +379,7 @@ class Scanner3(Scanner):
                     # pattr = 'code_object @ 0x%x %s->%s' %\
                     # (id(const), const.co_filename, const.co_name)
                     pattr = "<code_object " + const.co_name + ">"
-                elif isinstance(const, str):
+                elif isinstance(const, str) or xdis.PYTHON_VERSION <= 2.7 and isinstance(const, unicode):
                     opname = "LOAD_STR"
                 else:
                     if isinstance(inst.arg, int) and inst.arg < len(co.co_consts):
@@ -539,7 +539,7 @@ class Scanner3(Scanner):
 
         if show_asm in ("both", "after"):
             for t in tokens:
-                print(t.format(line_prefix="L."))
+                print(t.format(line_prefix=""))
             print()
         return tokens, customize
 
