@@ -67,7 +67,7 @@ from __future__ import print_function
 
 import re
 
-from xdis.code import iscode
+from xdis import iscode
 from xdis.magics import sysinfo2float
 from uncompyle6.semantics import pysource
 from uncompyle6 import parser
@@ -1163,6 +1163,7 @@ class FragmentsWalker(pysource.SourceWalker, object):
                 # modularity is broken here
                 p_insts = self.p.insts
                 self.p.insts = self.scanner.insts
+                self.p.offset2inst_index = self.scanner.offset2inst_index
                 ast = python_parser.parse(self.p, tokens, customize)
                 self.p.insts = p_insts
             except (python_parser.ParserError, AssertionError) as e:
@@ -1200,10 +1201,11 @@ class FragmentsWalker(pysource.SourceWalker, object):
             # modularity is broken here
             p_insts = self.p.insts
             self.p.insts = self.scanner.insts
+            self.p.offset2inst_index = self.scanner.offset2inst_index
             ast = parser.parse(self.p, tokens, customize)
             self.p.insts = p_insts
         except (parser.ParserError, AssertionError) as e:
-            raise ParserError(e, tokens)
+            raise ParserError(e, tokens, {})
 
         maybe_show_tree(self, ast)
 
