@@ -1,5 +1,5 @@
 #
-# (C) Copyright 2015-2018 by Rocky Bernstein
+# (C) Copyright 2015-2018, 2020 by Rocky Bernstein
 # (C) Copyright 2000-2002 by hartmut Goebel <h.goebel@crazy-compilers.com>
 #
 #  This program is free software: you can redistribute it and/or modify
@@ -27,10 +27,8 @@ from subprocess import call
 import uncompyle6
 from uncompyle6.scanner import (Token as ScannerToken, get_scanner)
 from uncompyle6 import PYTHON3
-from xdis.code import iscode
+from xdis import iscode, load_file, load_module, pretty_code_flags
 from xdis.magics import PYTHON_MAGIC_INT
-from xdis.load import load_file, load_module
-from xdis.util import pretty_flags
 
 # FIXME: DRY
 if PYTHON3:
@@ -352,8 +350,8 @@ def cmp_code_objects(version, is_pypy, code_obj1, code_obj2, verify,
             flags2 &= ~0x000000a0
             if flags1 != flags2:
                 raise CmpErrorMember(name, 'co_flags',
-                                     pretty_flags(flags1),
-                                     pretty_flags(flags2))
+                                     pretty_code_flags(flags1),
+                                     pretty_code_flags(flags2))
         else:
             # all other members must be equal
             if getattr(code_obj1, member) != getattr(code_obj2, member):
@@ -392,7 +390,7 @@ def compare_code_with_srcfile(pyc_filename, src_filename, verify):
     is returned. Otherwise a string message describing the mismatch is returned.
     """
     (version, timestamp, magic_int, code_obj1, is_pypy,
-     source_size) = load_module(pyc_filename)
+     source_size, sip_hash) = load_module(pyc_filename)
     if magic_int != PYTHON_MAGIC_INT:
         msg = ("Can't compare code - Python is running with magic %s, but code is magic %s "
                % (PYTHON_MAGIC_INT, magic_int))
@@ -417,9 +415,9 @@ def compare_code_with_srcfile(pyc_filename, src_filename, verify):
 def compare_files(pyc_filename1, pyc_filename2, verify):
     """Compare two .pyc files."""
     (version1, timestamp, magic_int1, code_obj1, is_pypy,
-     source_size) = uncompyle6.load_module(pyc_filename1)
+     source_size, sip_hash) = uncompyle6.load_module(pyc_filename1)
     (version2, timestamp, magic_int2, code_obj2, is_pypy,
-        source_size) = uncompyle6.load_module(pyc_filename2)
+        source_size, sip_hash) = uncompyle6.load_module(pyc_filename2)
     if (magic_int1 != magic_int2) and verify == 'verify':
          verify = 'weak_verify'
     cmp_code_objects(version1, is_pypy, code_obj1, code_obj2, verify)
